@@ -1,4 +1,5 @@
 from db_hj3415 import mongo2
+from db_path import MONGO_ADDR
 
 import logging
 logger = logging.getLogger(__name__)
@@ -11,9 +12,6 @@ logger.setLevel(logging.INFO)
 # 한개의 스파이더에서 연속 3일분량의 데이터가 전달된다.
 
 
-MONGO_ADDR = 'mongodb://192.168.0.173:27017'
-
-
 class Mongo2Pipeline:
     client = mongo2.connect_mongo(MONGO_ADDR)
 
