@@ -1,7 +1,7 @@
 # reference from https://livedata.tistory.com/27?category=1026425 (scrapy pipeline usage)
 from . import items
 from db_hj3415 import mongo2
-
+from db_path import MONGO_ADDR
 
 import logging
 logger = logging.getLogger(__name__)
@@ -12,9 +12,6 @@ logger.addHandler(ch)
 logger.setLevel(logging.INFO)
 
 
-MONGO_ADDR = 'mongodb://192.168.0.173:27017'
-
-
 class C101Pipeline:
     client = mongo2.connect_mongo(MONGO_ADDR)
     # c101에서 eps, bps, per, pbr을 수동으로 계산하여 입력하는 파이프라인
